//+------------------------------------------------------------------+
//|                                                 Stoch MaFibo.mq5 |
//|                        Copyright 2013, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2013, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\Signal\SignalStoch.mqh>
#include <Expert\Signal\SignalMA.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingParabolicSAR.mqh>
//--- available money management
#include <Expert\Money\MoneyFixedLot.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string             Expert_Title                 ="Stoch MaFibo"; // Document name
ulong                    Expert_MagicNumber           =2600;           // 
bool                     Expert_EveryTick             =false;          // 
//--- inputs for main signal
input int                Signal_ThresholdOpen         =10;             // Signal threshold value to open [0...100]
input int                Signal_ThresholdClose        =10;             // Signal threshold value to close [0...100]
input double             Signal_PriceLevel            =0.0;            // Price level to execute a deal
input double             Signal_StopLevel             =70.0;           // Stop Loss level (in points)
input double             Signal_TakeLevel             =12.0;           // Take Profit level (in points)
input int                Signal_Expiration            =4;              // Expiration of pending orders (in bars)
input int                Signal_0_Stoch_PeriodK       =34;             // Stochastic(34,5,5,...) K-period
input int                Signal_0_Stoch_PeriodD       =5;              // Stochastic(34,5,5,...) D-period
input int                Signal_0_Stoch_PeriodSlow    =5;              // Stochastic(34,5,5,...) Period of slowing
input ENUM_STO_PRICE     Signal_0_Stoch_Applied       =STO_CLOSECLOSE; // Stochastic(34,5,5,...) Prices to apply to
input double             Signal_0_Stoch_Weight        =1.0;            // Stochastic(34,5,5,...) Weight [0...1.0]
input int                Signal_1_Stoch_PeriodK       =55;             // Stochastic(55,8,8,...) K-period
input int                Signal_1_Stoch_PeriodD       =8;              // Stochastic(55,8,8,...) D-period
input int                Signal_1_Stoch_PeriodSlow    =8;              // Stochastic(55,8,8,...) Period of slowing
input ENUM_STO_PRICE     Signal_1_Stoch_Applied       =STO_CLOSECLOSE; // Stochastic(55,8,8,...) Prices to apply to
input double             Signal_1_Stoch_Weight        =1.0;            // Stochastic(55,8,8,...) Weight [0...1.0]
input int                Signal_2_Stoch_PeriodK       =100;            // Stochastic(100,8,8,...) K-period
input int                Signal_2_Stoch_PeriodD       =8;              // Stochastic(100,8,8,...) D-period
input int                Signal_2_Stoch_PeriodSlow    =8;              // Stochastic(100,8,8,...) Period of slowing
input ENUM_STO_PRICE     Signal_2_Stoch_Applied       =STO_CLOSECLOSE; // Stochastic(100,8,8,...) Prices to apply to
input double             Signal_2_Stoch_Weight        =1.0;            // Stochastic(100,8,8,...) Weight [0...1.0]
input int                Signal_MA_PeriodMA           =55;             // Moving Average(55,0,...) Period of averaging
input int                Signal_MA_Shift              =0;              // Moving Average(55,0,...) Time shift
input ENUM_MA_METHOD     Signal_MA_Method             =MODE_SMA;       // Moving Average(55,0,...) Method of averaging
input ENUM_APPLIED_PRICE Signal_MA_Applied            =PRICE_CLOSE;    // Moving Average(55,0,...) Prices series
input double             Signal_MA_Weight             =1.0;            // Moving Average(55,0,...) Weight [0...1.0]
//--- inputs for trailing
input double             Trailing_ParabolicSAR_Step   =0.002;          // Speed increment
input double             Trailing_ParabolicSAR_Maximum=0.2;            // Maximum rate
//--- inputs for money
input double             Money_FixLot_Percent         =10.0;           // Percent
input double             Money_FixLot_Lots            =0.1;            // Fixed volume
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- Initializing expert
   if(!ExtExpert.Init(Symbol(),Period(),Expert_EveryTick,Expert_MagicNumber))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing expert");
      ExtExpert.Deinit();
      return(-1);
     }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating signal");
      ExtExpert.Deinit();
      return(-2);
     }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalStoch
   CSignalStoch *filter0=new CSignalStoch;
   if(filter0==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter0");
      ExtExpert.Deinit();
      return(-3);
     }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.PeriodK(Signal_0_Stoch_PeriodK);
   filter0.PeriodD(Signal_0_Stoch_PeriodD);
   filter0.PeriodSlow(Signal_0_Stoch_PeriodSlow);
   filter0.Applied(Signal_0_Stoch_Applied);
   filter0.Weight(Signal_0_Stoch_Weight);
//--- Creating filter CSignalStoch
   CSignalStoch *filter1=new CSignalStoch;
   if(filter1==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter1");
      ExtExpert.Deinit();
      return(-4);
     }
   signal.AddFilter(filter1);
//--- Set filter parameters
   filter1.PeriodK(Signal_1_Stoch_PeriodK);
   filter1.PeriodD(Signal_1_Stoch_PeriodD);
   filter1.PeriodSlow(Signal_1_Stoch_PeriodSlow);
   filter1.Applied(Signal_1_Stoch_Applied);
   filter1.Weight(Signal_1_Stoch_Weight);
//--- Creating filter CSignalStoch
   CSignalStoch *filter2=new CSignalStoch;
   if(filter2==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter2");
      ExtExpert.Deinit();
      return(-5);
     }
   signal.AddFilter(filter2);
//--- Set filter parameters
   filter2.PeriodK(Signal_2_Stoch_PeriodK);
   filter2.PeriodD(Signal_2_Stoch_PeriodD);
   filter2.PeriodSlow(Signal_2_Stoch_PeriodSlow);
   filter2.Applied(Signal_2_Stoch_Applied);
   filter2.Weight(Signal_2_Stoch_Weight);
//--- Creating filter CSignalMA
   CSignalMA *filter3=new CSignalMA;
   if(filter3==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter3");
      ExtExpert.Deinit();
      return(-6);
     }
   signal.AddFilter(filter3);
//--- Set filter parameters
   filter3.PeriodMA(Signal_MA_PeriodMA);
   filter3.Shift(Signal_MA_Shift);
   filter3.Method(Signal_MA_Method);
   filter3.Applied(Signal_MA_Applied);
   filter3.Weight(Signal_MA_Weight);
//--- Creation of trailing object
   CTrailingPSAR *trailing=new CTrailingPSAR;
   if(trailing==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating trailing");
      ExtExpert.Deinit();
      return(-7);
     }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing trailing");
      ExtExpert.Deinit();
      return(-8);
     }
//--- Set trailing parameters
   trailing.Step(Trailing_ParabolicSAR_Step);
   trailing.Maximum(Trailing_ParabolicSAR_Maximum);
//--- Creation of money object
   CMoneyFixedLot *money=new CMoneyFixedLot;
   if(money==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating money");
      ExtExpert.Deinit();
      return(-9);
     }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing money");
      ExtExpert.Deinit();
      return(-10);
     }
//--- Set money parameters
   money.Percent(Money_FixLot_Percent);
   money.Lots(Money_FixLot_Lots);
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
     {
      //--- failed
      ExtExpert.Deinit();
      return(-11);
     }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
     {
      //--- failed
      printf(__FUNCTION__+": error initializing indicators");
      ExtExpert.Deinit();
      return(-12);
     }
//--- ok
   return(0);
  }
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   ExtExpert.Deinit();
  }
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
  {
   ExtExpert.OnTick();
  }
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
  {
   ExtExpert.OnTrade();
  }
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
  {
   ExtExpert.OnTimer();
  }
//+------------------------------------------------------------------+
